/*=================================================================================
FILE:			ogles_demo_03.cpp
  
DESCRIPTION:	This file is provide as a standard sample Brew source file. 
				Please refer to this OpenGL(R)ES brew sample application as a 
				reference on how to use the standard OpenGL-ES and EGL APIs.
                          
ABSTRACT:		The ogles_demo_03 application displays a skybox with 360 degree
				view that construct with six seamless textures.

AUTHOR:			QUALCOMM
                        
				Copyright (c) 2004 QUALCOMM Incorporated.
					   All Rights Reserved.
					QUALCOMM Proprietary/GTDR
=================================================================================*/

/*-------------------------------------------------------------------------------*
 *                      I N C L U D E   F I L E S                                *
 *-------------------------------------------------------------------------------*/

#include "ogles_demo_03.h"

/*-------------------------------------------------------------------------------*
 *       FOR OEM REFERENCE ONLY, USED ONLY FOR BUILDING STATIC APPLICATION       *
 *       Brew developers do not need this code snippet in their appliations      *
 *-------------------------------------------------------------------------------*/
#if defined(BREW_STATIC_APP)
extern "C"
{
	int   ogles_demo_03_CreateInstance(AEECLSID ClsId,IShell * pIShell,IModule * po,void ** ppObj);
	static int  ogles_demo_03_Load(IShell *ps, void * pHelpers, IModule ** pMod);

	// Constant Data...
	static const AEEAppInfo gai_ogles_demo_03 = { AEECLSID_OGLES_DEMO_03, OGLES_DEMO_03_RES_FILE, IDS_APPNAME, 0, 0, 0, 0, AFLAG_GAME };

	PFNMODENTRY ogles_demo_03_GetModInfo(IShell * ps, AEECLSID ** ppClasses, AEEAppInfo ** pApps, uint16 * pnApps, uint16 * pwMinPriv)
	{
	   *pApps = (AEEAppInfo *)&gai_ogles_demo_03;
	   *pnApps = 1;
	   return((PFNMODENTRY)ogles_demo_03_Load);
	}

	static int ogles_demo_03_Load(IShell *ps, void * pHelpers, IModule ** pMod)
	{
		return( AEEStaticMod_New((int16)(sizeof(AEEMod)),ps,pHelpers,pMod,ogles_demo_03_CreateInstance,NULL) );
	}
}
#endif  //BREW_STATIC_APP


/*-------------------------------------------------------------------------------*
 *                          B E G I N   P R O G R A M                            *
 *-------------------------------------------------------------------------------*/

/*===========================================================================
FUNCTION: AEEClsCreateInstance
  
DESCRIPTION:
	This function will create an instance for the ogles_demo_03 application 
  
PROTOTYPE:
	int AEEClsCreateInstance(AEECLSID ClsId,IShell * pIShell,IModule * po,void ** ppObj)
      
PARAMETERS:
	ClsId	: 32-bit ClassID of the requested interface
	pIShell	: pointer to the IShell Interface object
	po		: pointer to the IModlue Interface object
	ppObj	: pointer to the memory to fill with the pointer to the object
            
DEPENDENCIES
	none
              
RETURN VALUE
	AEE_SUCCESS	: if initialize was successful
	EFAILED		: if error occured
                
===========================================================================*/
#if defined(BREW_STATIC_APP)
int ogles_demo_03_CreateInstance(AEECLSID ClsId,IShell * pIShell,IModule * po,void ** ppObj)
#else
int AEEClsCreateInstance(AEECLSID ClsId,IShell * pIShell,IModule * po,void ** ppObj)
#endif
{
	*ppObj = NULL;
	
	if(ClsId == AEECLSID_OGLES_DEMO_03)
	{
		if(  AEEApplet_New(sizeof(ogles_demo_03), ClsId, pIShell, po, (IApplet**)ppObj,
			(AEEHANDLER)ogles_demo_03::HandleEvent,(PFNFREEAPPDATA)ogles_demo_03::Destroy)== TRUE )
		{
			return AEE_SUCCESS;
		}
	}
	return EFAILED;
}


/*===========================================================================
FUNCTION: ogles_demo_03::Init
  
DESCRIPTION:
	This function will initalize the ogles_demo_03 application 
  
PROTOTYPE:
	boolean ogles_demo_03::Init()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	TRUE	: if initialize was successful
	FALSE	: if error occured
                
===========================================================================*/
boolean ogles_demo_03::Init(void)
{

	DBGPRINTF("[Init] _X_INIT ROUTINE STARTED");
	// IGL and IEGL
	if( ISHELL_CreateInstance(m_applet.m_pIShell, AEECLSID_GL, (void **)&m_pIGL) != SUCCESS )
		return FALSE;
	else 
		// To use the standard OpenGL|ES APIs must call IGL_Init()
		IGL_Init(m_pIGL);


	if( ISHELL_CreateInstance(m_applet.m_pIShell, AEECLSID_EGL, (void **)&m_pIEGL) != SUCCESS )
		return FALSE;
	else
		// To use the standard EGL APIs must call IEGL_Init()
	   IEGL_Init(m_pIEGL);

	// File I/O
	if( ISHELL_CreateInstance( m_applet.m_pIShell, AEECLSID_FILEMGR, (void **)(&m_pIFileMgr) ) != SUCCESS )
	{
		CleanUp();	
		return FALSE;
	}

	// device frame buffer info
	if( IDISPLAY_GetDeviceBitmap(m_applet.m_pIDisplay, &m_pDDBitmap) != SUCCESS )
	{
		CleanUp();		
		return FALSE;
	}

	if( IBITMAP_GetInfo(m_pDDBitmap, &m_DDBitmapInfo, sizeof(AEEBitmapInfo)) != SUCCESS )
	{
		CleanUp();
		return FALSE;
	}

	// Setup GL/EGL 
	SetupEGL(); 
	SetupGL();

	counter = 0;
	isLoaded = 0;
	LoadTextures();

#ifdef AEE_SIMULATOR
	m_BoxspinFactor = 1;	//skybox auto spining
	m_frame_time = 50;
	m_skyboxspin=1;			//manual moving
#else
	m_BoxspinFactor = 12;	//skybox auto spining
	m_frame_time =25;
	m_skyboxspin=1;			//manual moving
#endif

	m_boxauto=TRUE;

	DBGPRINTF("[Init] _X_INIT ROUTINE OVER");

	return TRUE;
}


/*===========================================================================
FUNCTION: ogles_demo_03::Destroy
  
DESCRIPTION:
	This function provides a wrapper for the Brew exit routine. 
  
PROTOTYPE:
	void ogles_demo_03::Destroy(ogles_demo_03* p)
      
PARAMETERS:
	p: pointer to the ogles_demo_03 application instance
            
DEPENDENCIES
	static fucntion
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::Destroy(ogles_demo_03* p)
{
	p->CleanUp();
}


/*===========================================================================
FUNCTION: ogles_demo_03::CleanUp
  
DESCRIPTION:
	This function frees all resource for the application upon exit. 
  
PROTOTYPE:
	void ogles_demo_03::CleanUp()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::CleanUp(void)
{
	FreeTextureData();

	if (m_pDDBitmap)	IBITMAP_Release( m_pDDBitmap );
	if (m_pIFileMgr)	IFILEMGR_Release( m_pIFileMgr );

	if( eglMakeCurrent( EGL_NO_DISPLAY, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT ) == EGL_FALSE || eglGetError() != EGL_SUCCESS ){}
	if( eglDestroyContext( m_eglDisplay, m_eglContext ) == EGL_FALSE || eglGetError() != EGL_SUCCESS ){}
	if( eglDestroySurface( m_eglDisplay, m_eglSurface ) == EGL_FALSE || eglGetError() != EGL_SUCCESS ){}
	if( eglTerminate( m_eglDisplay ) == EGL_FALSE || eglGetError() != EGL_SUCCESS ){}

	// MUST CALL IGL/IEGL RELEASE LAST, NO EGL OR GL calls will work after you release the interfaces.
	if (m_pIEGL)		IEGL_Release( m_pIEGL     );
	if (m_pIGL)			IGL_Release( m_pIGL      );

}

/*===========================================================================
FUNCTION: ogles_demo_03::FreeTextureData
  
DESCRIPTION:
	This function frees the texture data
  
PROTOTYPE:
	void ogles_demo_03::FreeTextureData()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::FreeTextureData(void)
{

	glDeleteTextures(1, &m_boxTopTexture);
	glDeleteTextures(1, &m_boxBottomTexture);
	glDeleteTextures(1, &m_boxLeftTexture);
	glDeleteTextures(1, &m_boxRightTexture);
	glDeleteTextures(1, &m_boxFrontTexture);
	glDeleteTextures(1, &m_boxBackTexture);
	
	for (int i=0; i<6; i++)
		FREE(imageData[i]);

	*imageData = NULL;
}

/*===========================================================================
FUNCTION: ogles_demo_03::HandleEvent
  
DESCRIPTION:
	All events to the ogles_demo_03 application are handled in this function. 
  
PROTOTYPE:
	boolean ogles_demo_03::HandleEvent( ogles_demo_03 *p, AEEEvent event, uint16 wParam, uint32 dwParam )
      
PARAMETERS:
	p		: pointer to a ogles_demo_03 application instance
	event	: the event that needs to be handled
	wParam	: Event specific data.
	dwParam	: Event specific data.
            
DEPENDENCIES
	none
              
RETURN VALUE
	TRUE	: If the event has been processed 
	FALSE	: If the event was not vaild or processed
                
===========================================================================*/
boolean ogles_demo_03::HandleEvent( ogles_demo_03 *p, AEEEvent event, uint16 wParam, uint32 dwParam )
{
	
	switch (event) 
	{
		case EVT_APP_START:
		case EVT_APP_RESUME:
			// intialize the applet
			p->Init();
//			p->RenderSkybox();
//			p->m_frame_time=1;
			NextFrame(p);
			DBGPRINTF("initialized");
			return TRUE;
			break;
		case EVT_APP_SUSPEND:
			p->CleanUp();
			ISHELL_CancelTimer( p->m_applet.m_pIShell, NULL, (void *)p );
			return TRUE;
				
		case EVT_APP_NO_SLEEP:
			return TRUE;
				
		case EVT_COMMAND:
			break;
				
		case EVT_KEY_PRESS:
			p->m_key_state = 1;
			p->m_key_wParam = wParam;	
			if (p->KeyEvent(wParam))
				return HandleEvent(p, EVT_KEY, wParam, dwParam);
			else
				return TRUE;
			break;
				
		case EVT_KEY_RELEASE:	
			p->m_key_state =0;
			p->m_key_wParam = wParam;
			return TRUE;
				
			break;
				
		case EVT_KEY:
			return (p->KeyEvent(wParam));
			break;

		default:
			break;
				
	}
	
	return  FALSE; 
	

}

/*===========================================================================
FUNCTION: ogles_demo_03::KeyEvent
  
DESCRIPTION:
	All key events to the ogles_demo_03 application are handled in this function. 
  
PROTOTYPE:
	boolean ogles_demo_03::KeyEvent( uint16 wParam)
      
PARAMETERS:
	wParam:   Event specific data.
            
DEPENDENCIES
	none
              
RETURN VALUE
	TRUE	: If the event has been processed 
	FALSE	: If the event was not vaild or processed
                
===========================================================================*/
boolean ogles_demo_03::KeyEvent(uint16 wParam)
{

	switch(wParam)
	{
		
		case AVK_CLR:
			ISHELL_CancelTimer( m_applet.m_pIShell, NULL, (void *)this ) ;
			return FALSE;
			break;

		case AVK_SELECT:
			m_boxauto=TRUE;
			return TRUE;
			break;

		case AVK_LEFT:
			m_boxauto=FALSE;
			m_skyboxRotX-=m_skyboxspin;
			return TRUE;

		case AVK_RIGHT:
			m_boxauto=FALSE;
			m_skyboxRotX+=m_skyboxspin;
			return TRUE;

		case AVK_UP:
			//m_boxbounce++;
			//if (m_boxbounce>=1)
			//{
				m_skyboxRotY+=m_skyboxspin;
			//	m_boxbounce=0;
			//}
			return TRUE;

		case AVK_DOWN:
			//m_boxbounce++;
			//if (m_boxbounce>=1)
			//{
				m_skyboxRotY-=m_skyboxspin;
			//	m_boxbounce=0;
			//}
			return TRUE;

		case AVK_1:
			//m_boxbounce++;
			//if (m_boxbounce>=3)
			//{
				m_skyboxMove+=m_skyboxspin;
			//	m_boxbounce=0;
			//}
			return TRUE;

		case AVK_2:
			//m_boxbounce++;
			//if (m_boxbounce>=3)
			//{
				m_skyboxMove-=m_skyboxspin;
			//	m_boxbounce=0;
			//}
			return TRUE;

		case AVK_3: 
		case AVK_4:     
		case AVK_5:    
		case AVK_6:
		case AVK_7:
		case AVK_8:
		case AVK_9:
		case AVK_STAR:
		case AVK_0:
		case AVK_POUND:

		default:
			return FALSE;
			break;
    }
	
	return FALSE;
   
}


/*===========================================================================
FUNCTION: ogles_demo_03::SetupEGL
  
DESCRIPTION:
	This routine is used for EGL setup.  
   
PROTOTYPE:
	boolean ogles_demo_03::SetupEGL()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	TRUE	: if no errors
	FALSE	: if an error occured
                
===========================================================================*/
boolean ogles_demo_03::SetupEGL(void)
{

	EGLConfig myConfig;
	EGLint ncfg = 1;
	EGLint params[5] = {EGL_NONE,EGL_NONE,EGL_NONE,EGL_NONE,EGL_NONE};
	
	// Init State Data
	m_eglDisplay		= EGL_NO_DISPLAY;
	m_eglSurface		= EGL_NO_SURFACE;
	m_eglContext		= EGL_NO_CONTEXT;
	
	// Main Display
	m_eglDisplay = eglGetDisplay( m_applet.m_pIDisplay );
	if( m_eglDisplay == EGL_NO_DISPLAY || eglGetError() != EGL_SUCCESS ) 
		return FALSE;
	
	if( eglInitialize( m_eglDisplay, NULL, NULL ) == EGL_FALSE || eglGetError() != EGL_SUCCESS )
		return FALSE;
	
	// Get Configuration	
	eglGetConfigs( m_eglDisplay, &myConfig, 1, &ncfg );
	
	
	// Window Surface
	{
		IDIB *pDIB;
		
		if( IBITMAP_QueryInterface(m_pDDBitmap, AEECLSID_DIB, (void**)&pDIB) != SUCCESS )
			return EFAILED;
		
		m_eglSurface = eglCreateWindowSurface( m_eglDisplay, myConfig, pDIB, params );
		
		IDIB_Release( pDIB );
		
		if( m_eglSurface == EGL_NO_SURFACE || eglGetError() != EGL_SUCCESS )
			return FALSE;
	}
	
	// Context
	m_eglContext = eglCreateContext( m_eglDisplay, myConfig, 0, 0 );
	if( m_eglContext == EGL_NO_CONTEXT || eglGetError() != EGL_SUCCESS )
		return FALSE;
	
	if( eglMakeCurrent( m_eglDisplay, m_eglSurface, m_eglSurface, m_eglContext ) == EGL_FALSE || eglGetError() != EGL_SUCCESS )
		return FALSE;
	
	return TRUE;
}

/*===========================================================================
FUNCTION: ogles_demo_03::SetupGL
  
DESCRIPTION:
	This routine is used for GL setup.  
   
PROTOTYPE:
	boolean ogles_demo_03::SetupGL()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	TRUE	: if no errors
	FALSE	: if an error occured
                
===========================================================================*/
boolean ogles_demo_03::SetupGL(void)
{
	
	// Smooth shading
	glShadeModel( GL_SMOOTH );
	
	// Depth Test
	glEnable( GL_DEPTH_TEST );
	
	// Perspective Correction
	glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST );
	
	// GL Initialization
	glViewport( 0, 0, GetScreenWidth(), GetScreenHeight() );
	
	// Init Projection Matrix
	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	
	
	glDisable(GL_LIGHTING);
	glDisable(GL_BLEND);
		
	// GL Initialization
	glViewport( 0, 0, GetScreenWidth(), GetScreenHeight() );
	
	// Init Projection Matrix
	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	
	glFrustumx(		INT_TO_Q16(-5),	INT_TO_Q16(5),
					INT_TO_Q16(-5),	INT_TO_Q16(5),
					INT_TO_Q16(10),	INT_TO_Q16(100)	);
	
	glMatrixMode( GL_MODELVIEW );
	glLoadIdentity();
	
	if (glGetError() != EGL_SUCCESS) return FALSE;
	
	return TRUE;
	

}

/*===========================================================================
FUNCTION: ogles_demo_03::NextFrame
  
DESCRIPTION:
	This routine sets up the frame timer, and then renders the next frame  
   
PROTOTYPE:
	void ogles_demo_03::NextFrame(ogles_demo_03* p)
      
PARAMETERS:
	p: pointer to the ogles_demo_03 application instance
            
DEPENDENCIES
	static fucntion
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::NextFrame(ogles_demo_03* p)
{	
	p->RenderFrame();

	if (p->m_key_state ==1) 
		p->KeyEvent(p->m_key_wParam);

	ISHELL_SetTimer( p->m_applet.m_pIShell, p->m_frame_time,(PFNNOTIFY) NextFrame,(void*)p);
}


/*===========================================================================
FUNCTION: ogles_demo_03::RenderFrame
  
DESCRIPTION:
	The main rendering routine for the ogles_demo_03 application  
   
PROTOTYPE:
	void ogles_demo_03::RenderFrame()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::RenderFrame(void)
{

    RenderSkybox();
		
	// Swap the Buffers
	eglSwapBuffers( m_eglDisplay, m_eglSurface );	
}

/*===========================================================================
FUNCTION: ogles_demo_03::LoadTextures
  
DESCRIPTION:
	This function loads the textures for this application 

PROTOTYPE:
	void ogles_demo_03::LoadTextures()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	none
                
===========================================================================*/
void ogles_demo_03::LoadTextures(void)
{
	DBGPRINTF("LoadTextures() step=%d\n",1);
	if (!isLoaded)
	{

		isLoaded = TRUE;
		DBGPRINTF("LoadTextures() step=load true\n");

		int imageW, imageH;

		for (int i=0; i<6; i++)
		{
			if (i == 0)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_top.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxTopTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxTopTexture);
			}
			else if (i == 1)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_bottom.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxBottomTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxBottomTexture);
			}
			else if (i == 2)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_left.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxLeftTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxLeftTexture);
			}
			else if (i == 3)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_right.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxRightTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxRightTexture);
			}
			else if (i == 4)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_front.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxFrontTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxFrontTexture);
			}
			else if (i == 5)			
			{
				imageData[i] = PPMToTexture( m_applet.m_pIShell, "skybox_back.ppm", &imageW, &imageH );
				glGenTextures(1, &m_boxBackTexture);
				glBindTexture(GL_TEXTURE_2D, m_boxBackTexture);
			}

			glTexParameterx(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
			glTexParameterx(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
			glTexParameterx(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
			glTexParameterx(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
			glTexEnvx(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);

			glPixelStorei(GL_UNPACK_ALIGNMENT, 1);

			if(imageData[i])
			{
				glTexImage2D(	GL_TEXTURE_2D,		// target
								0,					// level
								GL_RGB,				// internalformat
								imageW,				// width
								imageH,				// height
								0,					// border
								GL_RGB,				// format
								GL_UNSIGNED_BYTE,	// datatype
								imageData[i]);		// pixels
			}
		}

		m_skybox.m_textures[skybox::SKY_TOP]	= m_boxTopTexture;
		m_skybox.m_textures[skybox::SKY_BOTTOM]	= m_boxBottomTexture;
		m_skybox.m_textures[skybox::SKY_FRONT]	= m_boxBackTexture;
		m_skybox.m_textures[skybox::SKY_BACK]	= m_boxFrontTexture;
		m_skybox.m_textures[skybox::SKY_RIGHT]	= m_boxRightTexture;
		m_skybox.m_textures[skybox::SKY_LEFT]	= m_boxLeftTexture;
	}
}

/*===========================================================================
FUNCTION: ogles_demo_03::RenderSkybox
  
DESCRIPTION:
	The rendering the sky box routine for the ogles_demo_03 application  
   
PROTOTYPE:
	void ogles_demo_03::RenderSkybox()
      
PARAMETERS:
	none
            
DEPENDENCIES
	none
              
RETURN VALUE
	none
                
===========================================================================*/

void ogles_demo_03::RenderSkybox(void)
{
	
	//DBGPRINTF("RenderCube() step=%d\n",1);		  
	int v=0;
	int32 ViewMatrixFx[16];

	glDisable( GL_DEPTH_TEST );

	m_frame_time =1 ;
	glShadeModel( GL_FLAT );

	glTexEnvx(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_REPLACE);

	glHint( GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST );

	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

	glPushMatrix();

	glMatrixMode( GL_MODELVIEW );
	glLoadIdentity();

    // Constrain how far we allow zooming like movement
	if(m_skyboxMove>7)			m_skyboxMove=7;
	else if (m_skyboxMove <-7)	m_skyboxMove=-7;

    // Constrain how far up and down we allow the skybox to rotate
	if(m_skyboxRotY>12)			m_skyboxRotY=12;
	else if (m_skyboxRotY <-12)	m_skyboxRotY=-12;

    // Create a view matrix of where to look at
	xxgluLookAtMatrixFx(ViewMatrixFx, 
                        0,0,INT_TO_Q16(m_skyboxMove-10),    // position of viewer

                        0, (m_skyboxRotY << 14), 0,         // Where to look
                                                            // Note: the shift left by 14
                                                            //       is so that the rotation
                                                            //       goes 1/4 the speed 
                                                            //       of using INT_TO_Q16

                        0, INT_TO_Q16(1), 0 );              // Up axis

    // Apply the view matrix
	glMultMatrixx((GLfixed*)ViewMatrixFx);

	v = INT_TO_Q16(12);

	m_autoboxrotx = INT_TO_Q16(counter)+INT_TO_Q16(m_skyboxRotX);

	if (m_boxauto)
	{
		counter+=m_BoxspinFactor;
		glRotatex(m_autoboxrotx, INT_TO_Q16(0), INT_TO_Q16(1), INT_TO_Q16(0));
	}
	else
	{
		glRotatex(m_autoboxrotx, INT_TO_Q16(0), INT_TO_Q16(1), INT_TO_Q16(0));
	}


	{
		GLint vertices[72] = {
			// bottom
			-v, -v, v,		-v, -v, -v,		v,  -v, -v,		v,  -v, v,
			// top
			-v, v, v,		v,  v, v,		v,  v, -v,		-v, v, -v,
			// left
			-v, -v, -v,		-v, -v, v,		-v, v, v,		-v, v, -v,
			//right
			v, -v, v,		v, -v, -v,		v, v, -v,		v, v, v,
			// front
			-v, -v, v,		v,  -v, v,		v,  v, v,		-v, v, v,
			// back
			v,  -v, -v,		-v, -v, -v,		-v, v, -v,		v,  v, -v };

		GLubyte indices[24] = {
			0, 1, 2, 3,
			4, 5, 6, 7,
			8, 9, 10, 11,
			12, 13, 14, 15,
			16, 17, 18, 19,
			20, 21, 22, 23 };

		GLshort texCoords [48] = {
			1, 1, 0, 1, 0, 0, 1, 0,
			1, 1, 0, 1, 0, 0, 1, 0,
			1, 1, 0, 1, 0, 0, 1, 0,
			1, 1, 0, 1, 0, 0, 1, 0,
			1, 1, 0, 1, 0, 0, 1, 0,
			1, 1, 0, 1, 0, 0, 1, 0
			};


		glEnableClientState(GL_VERTEX_ARRAY);

		glEnable(GL_TEXTURE_2D);
		glEnableClientState(GL_TEXTURE_COORD_ARRAY);
		glTexCoordPointer(2, GL_SHORT, 0, texCoords);

		glVertexPointer(3, GL_FIXED, 0, vertices);

		glBindTexture(GL_TEXTURE_2D, m_boxBottomTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 0 * 4);				

		glBindTexture(GL_TEXTURE_2D, m_boxTopTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 1 * 4);

		glBindTexture(GL_TEXTURE_2D, m_boxRightTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 2 * 4);

		glBindTexture(GL_TEXTURE_2D, m_boxLeftTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 3 * 4);

		glBindTexture(GL_TEXTURE_2D, m_boxFrontTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 4 * 4);

		glBindTexture(GL_TEXTURE_2D, m_boxBackTexture);
		glDrawElements(GL_TRIANGLE_FAN, 4, GL_UNSIGNED_BYTE, indices + 5 * 4);
							
		glDisableClientState(GL_VERTEX_ARRAY);
		glDisableClientState(GL_COLOR_ARRAY);
		glDisableClientState(GL_TEXTURE_COORD_ARRAY);
		glDisable(GL_TEXTURE_2D);
	}

	glPopMatrix();

	glShadeModel( GL_FLAT );

}

