#ifndef __egltypes_h_
#define __egltypes_h_

/*
** Copyright 2002-2003 Promoters of the Khronos Group (3Dlabs, ARM Ltd.,
** ATI Technologies, Inc., Discreet, Ericsson Mobile, Imagination
** Technologies Group plc, Motorola, Inc., Nokia, Silicon Graphics, Inc.,
** SK Telecom, and Sun Microsystems).
**
** This document is protected by copyright, and contains information
** proprietary to The Khronos Group. Any copying, adaptation, distribution,
** public performance, or public display of this document without the
** express written consent of the copyright holders is strictly prohibited.
** The receipt or possession of this document does not convey any rights to
** reproduce, disclose, or distribute its contents, or to manufacture, use,
** or sell anything that it may describe, in whole or in part.
*/

// Windows operating system
#ifdef _WIN32
    
    // Define EGL_API for import/export
#   ifdef __GL_EXPORTS
#       define GL_API __declspec(dllexport)
#   else
#       define GL_API __declspec(dllimport)
#   endif


    // Set up native display, window, and pixmap types
    //   Our current implementation doesn't really need the
    //   native display type so its unclear what this should
    //   be for windows, but the best bet is the display name
    //   as used by EnumDisplayDevices, EnumDisplaySettings, 
    //   and ChangeDisplaySettingsEx. 

// BREW
#if defined(AEE_SIMULATOR) || defined(BREW_STATIC_APP) || defined(DYNAMIC_APP) 
#	ifdef FEATURE_GRAPHICS_NATIVE_WINDOWTYPE_GIGA
		#include "g2d.h"
		#include "cal.h"
		#include "g2DTypedef.h"

		typedef HIMAGE NativePixmapType;
		typedef HIMAGE NativeWindowType;
		typedef G2D_LCD NativeDisplayType;
#	else
		typedef IDIB*			NativePixmapType;
		typedef IDIB*			NativeWindowType;
		typedef IDisplay*		NativeDisplayType;
#	endif
#else
    // Include windows header
#   include <windows.h>

#   define NativeDisplayType const char*
#   define NativeWindowType  HWND
#   define NativePixmapType  HBITMAP

#endif
// Other operating systems (create special cases as needed)
#else


    // Define EGL_API to do nothing
#   ifdef __GL_EXPORTS
#       define GL_API
#   else
#       define GL_API extern
#   endif
	

    // Set up native display, window, pixmap types

// BREW
#if defined(AEE_SIMULATOR) || defined(BREW_STATIC_APP) || defined(DYNAMIC_APP) 
#	ifdef FEATURE_GRAPHICS_NATIVE_WINDOWTYPE_GIGA
		#include "g2d.h"
		#include "cal.h"
		#include "g2DTypedef.h"

		typedef HIMAGE NativePixmapType;
		typedef HIMAGE NativeWindowType;
		typedef G2D_LCD NativeDisplayType;
#	else
		typedef IDIB*			NativePixmapType;
		typedef IDIB*			NativeWindowType;
		typedef IDisplay*		NativeDisplayType;
#	endif
#else

#   define NativeWindowType  void*
#   define NativePixmapType  void*
#   define NativeDisplayType void*

#endif

#endif

#define GL_APIENTRY 

typedef int				EGLint;
typedef unsigned int	EGLBoolean;
typedef void *			EGLConfig;
typedef void *			EGLContext;
typedef void *			EGLDisplay;
typedef void *			EGLSurface;

/*
** EGL and native handle values
*/
#define EGL_DEFAULT_DISPLAY ((NativeDisplayType)0)
#define EGL_NO_CONTEXT ((EGLContext)0)
#define EGL_NO_DISPLAY ((EGLDisplay)0)
#define EGL_NO_SURFACE ((EGLSurface)0)


#endif /* ___egltypes_h_ */
